==> mall-center-api-0.1.13.21-20211123.071228-1-sources.jar: cn/com/duiba/mall/center/api/domain/dto/discount/DiscountListQueryDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.discount;

import cn.com.duiba.mall.center.api.domain.paramquary.PageQueryParam;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by zhangyongjie on 2021/11/18 7:42 下午
 * 优惠券列表查询条件
 */
public class DiscountListQueryDto extends PageQueryParam implements Serializable {

    /**
     * 优惠券id
     */
    private Long id;

    /**
     * 应用id
     */
    private Long appId;

    /**
     * 优惠券名称
     */
    private String discountTitle;

    /**
     * 优惠券类型
     */
    private Integer discountType;

    /**
     * 创建时间开始范围
     */
    private Date beginTime;

    /**
     * 创建时间结束范围
     */
    private Date endTime;

    /**
     * 优惠券状态
     */
    private Integer discountStatus;


    /**
     * 优惠券使用范围
     */
    private Integer discountScope;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDiscountTitle() {
        return discountTitle;
    }

    public void setDiscountTitle(String discountTitle) {
        this.discountTitle = discountTitle;
    }

    public Integer getDiscountType() {
        return discountType;
    }

    public void setDiscountType(Integer discountType) {
        this.discountType = discountType;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getDiscountStatus() {
        return discountStatus;
    }

    public void setDiscountStatus(Integer discountStatus) {
        this.discountStatus = discountStatus;
    }

    public Integer getDiscountScope() {
        return discountScope;
    }

    public void setDiscountScope(Integer discountScope) {
        this.discountScope = discountScope;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }
}

==> mall-center-api-0.1.33-20251013.092126-2-sources.jar: cn/com/duiba/mall/center/api/domain/dto/discount/DiscountListQueryDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.discount;

import cn.com.duiba.mall.center.api.domain.paramquary.PageQueryParam;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by zhangyongjie on 2021/11/18 7:42 下午
 * 优惠券列表查询条件
 */
public class DiscountListQueryDto extends PageQueryParam implements Serializable {

    /**
     * 优惠券id
     */
    private Long id;

    /**
     * 应用id
     */
    private Long appId;

    /**
     * 优惠券名称
     */
    private String discountTitle;

    /**
     * 优惠券类型
     */
    private Integer discountType;

    /**
     * 创建时间开始范围
     */
    private Date beginTime;

    /**
     * 创建时间结束范围
     */
    private Date endTime;

    /**
     * 优惠券状态
     */
    private Integer discountStatus;


    /**
     * 优惠券时间维度状态
     */
    private Integer discountTimeStatus;


    /**
     * 优惠券使用范围
     */
    private Integer discountScope;



    public Integer getDiscountTimeStatus() {
        return discountTimeStatus;
    }

    public void setDiscountTimeStatus(Integer discountTimeStatus) {
        this.discountTimeStatus = discountTimeStatus;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDiscountTitle() {
        return discountTitle;
    }

    public void setDiscountTitle(String discountTitle) {
        this.discountTitle = discountTitle;
    }

    public Integer getDiscountType() {
        return discountType;
    }

    public void setDiscountType(Integer discountType) {
        this.discountType = discountType;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getDiscountStatus() {
        return discountStatus;
    }

    public void setDiscountStatus(Integer discountStatus) {
        this.discountStatus = discountStatus;
    }

    public Integer getDiscountScope() {
        return discountScope;
    }

    public void setDiscountScope(Integer discountScope) {
        this.discountScope = discountScope;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }
}
